#[repr(C)]pub struct Storage<T> {
val: UnsafeCell<T>,
state: Cell<State>,
}🔬This is a nightly-only experimental API. (
thread_local_internals)Fields
val: UnsafeCell<T>🔬This is a nightly-only experimental API. (
thread_local_internals)state: Cell<State>🔬This is a nightly-only experimental API. (
thread_local_internals)Implementations
Sourceimpl<T> Storage<T>
impl<T> Storage<T>
pub const fn new(val: T) -> Storage<T>
🔬This is a nightly-only experimental API. (
thread_local_internals)Sourcepub unsafe fn get(&self) -> *const T
🔬This is a nightly-only experimental API. (thread_local_internals)
pub unsafe fn get(&self) -> *const T
thread_local_internals)Gets a pointer to the TLS value. If the TLS variable has been destroyed, a null pointer is returned.
The resulting pointer may not be used after thread destruction has occurred.
Safety
The self reference must remain valid until the TLS destructor is run.
unsafe fn get_or_init_slow(&self) -> *const T
🔬This is a nightly-only experimental API. (
thread_local_internals)Auto Trait Implementations
impl<T> !Freeze for Storage<T>
impl<T> !RefUnwindSafe for Storage<T>
impl<T> !Sync for Storage<T>
impl<T> Send for Storage<T>where
T: Send,
impl<T> Unpin for Storage<T>where
T: Unpin,
impl<T> UnsafeUnpin for Storage<T>where
T: UnsafeUnpin,
impl<T> UnwindSafe for Storage<T>where
T: UnwindSafe,